=========
Cartridge
=========

Welcome to the Cartridge project. Cartridge is a shopping cart application
built using the `Django`_ framework. It is `BSD licensed`_ and designed to
provide a clean and simple base for developing e-commerce websites.

Cartridge also extends the `Mezzanine`_ content management platform. A live
demo of Cartridge can be found by visiting the `Mezzanine live demo`_.

To learn more about Cartridge, please read the :doc:`overview`, which contains
a features list, an installation guide, and other general information.

.. toctree::
    :maxdepth: 2

    overview
    components
    integration
    configuration
    model-graph
    colophon


.. _`Django`: http://djangoproject.com/
.. _`BSD licensed`: http://www.linfo.org/bsdlicense.html
.. _`Mezzanine live demo`: http://mezzanine.jupo.org/
.. _`Mezzanine`: http://mezzanine.jupo.org/
